@@ -1,5 +1,5 @@
 package Bio::Roary;
-$Bio::Roary::VERSION = '3.8.2';
+$Bio::Roary::VERSION = '3.9.1';
 # ABSTRACT: Create a pan genome
 
 
@@ -43,6 +43,7 @@ has 'core_definition'             => ( is => 'rw', isa => 'Num',      default  =
 has 'verbose'                     => ( is => 'rw', isa => 'Bool',     default  => 0 );
 has 'mafft'                       => ( is => 'ro', isa => 'Bool',     default  => 0 );
 has 'inflation_value'             => ( is => 'rw', isa => 'Num',      default  => 1.5 );
+has 'allow_paralogs'              => ( is => 'rw', isa => 'Bool',     default => 0 );
 
 has 'output_multifasta_files' => ( is => 'ro', isa => 'Bool', default => 0 );
 
@@ -131,6 +132,7 @@ sub run {
         core_definition             => $self->core_definition,
 		verbose                     => $self->verbose,
 		mafft                       => $self->mafft,
+		allow_paralogs              => $self->allow_paralogs,
     );
     $post_analysis->run();
 
@@ -154,7 +156,7 @@ Bio::Roary - Create a pan genome
 
 =head1 VERSION
 
-version 3.8.2
+version 3.9.1
 
 =head1 SYNOPSIS
 
